@@ -9,7 +9,7 @@ sub debug {
     my ($self, $msg) = @_;
     my ($package, $filename, $line, $sub, @foo) = caller(1);
     $sub =~ s/Schedule::Chronic:://;
-    print STDERR "debug: $sub() - $msg\n" if $self->{debug};
+    $self->{logger}->logthis("$msg");
 
 }
 
